Result (imandrax-ocaml.Imandrax_ocaml_prelude.Prelude_extracted.Result)

`type ('a, 'b) t = ('a, 'b) result`
`val return : 'a -> ('a, 'b) result`
`val fail : 'a -> ('b, 'a) result`
`val map : ('a -> 'b) -> ('a, 'c) result -> ('b, 'c) result`
`val map_err : ('a -> 'b) -> ('c, 'a) result -> ('c, 'b) result`
`val get_or : default:'a -> ('a, 'b) result -> 'a`
`val map_or : default:'a -> ('b -> 'a) -> ('b, 'c) result -> 'a`
`val (>|=) : ('a, 'b) result -> ('a -> 'c) -> ('c, 'b) result`
`val flat_map : ('a -> ('b, 'c) result) -> ('a, 'c) result -> ('b, 'c) result`
`val (>>=) : ('a, 'b) result -> ('a -> ('c, 'b) result) -> ('c, 'b) result`
`val fold : ('a -> 'b) -> ('c -> 'b) -> ('a, 'c) result -> 'b`
`val is_ok : ('a, 'b) result -> bool`
`val is_error : ('a, 'b) result -> bool`
`val monoid_product : ('a, 'b) result -> ('c, 'b) result -> ('a * 'c, 'b) result`
`val let+ : ('a, 'b) result -> ('a -> 'c) -> ('c, 'b) result`
`val and+ : ('a, 'b) result -> ('c, 'b) result -> ('a * 'c, 'b) result`
`val let* : ('a, 'b) result -> ('a -> ('c, 'b) result) -> ('c, 'b) result`
`val and* : ('a, 'b) result -> ('c, 'b) result -> ('a * 'c, 'b) result`